PhormLogger class abstract interface

Interface for PHORM logging.

Implement this to route PHORM logs to your preferred logging service (e.g. Firebase Crashlytics, Datadog, or custom file loggers).

Implementers

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

error(String message, [Object? error, StackTrace? stackTrace]) → void
Logs an error with optional stack trace.
info(String message) → void
Logs an informational message.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
query(String sql, List<Object?>? arguments, Duration duration) → void
Logs a database query, execution time, and arguments.
slowQuery(String sql, List<Object?>? arguments, Duration duration) → void
Logs a slow query that exceeded the defined threshold.
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited