Column class
Standard column definition.
Used for most non-key fields.
- Inheritance
-
- Object
- ColumnBase
- Column
Constructors
-
Column({String? sqlType, SqlType? type, String? columnName, bool unique = false, dynamic defaultValue, List<
IValidator> ? validators, ValueConverter? converter, String? collate}) -
Creates a
@Columnannotation.const
Properties
- collate → String?
-
Optional collation sequence.
finalinherited
- columnName → String?
-
Explicit name of the column in the database.
finalinherited
- converter → ValueConverter?
-
Optional value converter for mapping between Dart and SQL types.
finalinherited
- defaultValue → dynamic
-
Default value used when no value is provided.
finalinherited
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- sqlType → String?
-
Database data type of the column.
finalinherited
- type → SqlType?
-
Concrete SQL type class definition (e.g. VARCHAR(256), DECIMAL(10, 2)).
finalinherited
- unique → bool
-
Whether the column enforces uniqueness.
finalinherited
-
validators
→ List<
IValidator> ? -
Optional value constraint.
finalinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited